==============
tariochbctools
==============

Some importers, plugins and price fetchers for the double-entry bookkeeping software `Beancount <https://beancount.github.io/>`__.

Contents
========

.. toctree::
   :maxdepth: 3

   Installation <installation>
   Importers <importers>
   Plugins <plugins>
   Price Fetchers <price_fetchers>
   License <license>
   Module Reference <api/modules>


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
